<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H1_About_Right extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h1_about_right';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H1 About Right', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h1_about_right',
			[
				'label' => esc_html__( 'H1 About Right', 'optcare' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
	

	$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'optcare' ),
			]
		);
		
		
	$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'optcare' ),
			]
		);

	$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'optcare' ),
			]
		);
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Feature Block', 'optcare' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'optcare')],
							],
						'fields' => 
							[		
		
							'block_subtitle2'=>	
							
									[
										'name' => 'block_subtitle2',
										'label' => esc_html__('Subtitle', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],	
									
							'block_text2'=>			
									
									[
										'name' => 'block_text2',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],
									
							
							'block_text3'=>			
									
									[
										'name' => 'block_text3',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],
									
							'block_text4'=>			
									
									[
										'name' => 'block_text4',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],
							
							'block_icons'=>			
									[
										'name' => 'block_icons',
										'label' => esc_html__('Enter The icons', 'optcare'),
										'type' => Controls_Manager::SELECT,
										'options'  => get_fontawesome_icons(),
									],
		
									
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		
		 <!-- about-section -->
        <section class="about-section <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 content-column">
                        <div class="content_block_one">
                            <div class="content-box ml_30">
                                <div class="sec-title left p_relative d_block mb_25">
                                    <span class="sub-title"><?php echo $settings['subtitle'];?></span>
                                    <h2><?php echo $settings['title'];?></h2>
                                </div>
                                <div class="text p_relative d_block">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <div class="inner-box">
                                    <div class="row clearfix">
									<?php foreach($settings['repeat'] as $item):?>	
                                        <div class="col-lg-6 col-md-6 col-sm-12 single-column">
                                            <div class="single-item">
                                                <h3><?php echo wp_kses($item['block_subtitle2'], $allowed_tags);?></h3>
                                                <ul class="list-style-one clearfix">
                                                    <li><?php echo wp_kses($item['block_text2'], $allowed_tags);?></li>
                                                    <li><?php echo wp_kses($item['block_text3'], $allowed_tags);?></li>
                                                    <li><?php echo wp_kses($item['block_text4'], $allowed_tags);?></li>
                                                </ul>
                                            </div>
                                        </div>
									<?php endforeach; ?>	
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        
		<?php 
	}

}