<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H1_Contact extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h1_contact';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H1 Contact', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h1_contact',
			[
				'label' => esc_html__( 'H1 Contact', 'optcare' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
	

	$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'optcare' ),
			]
		);
		
	$this->add_control(
		'subtitle',
		[
			'label'       => __( 'Sub Title', 'optcare' ),
			'type'        => Controls_Manager::TEXTAREA,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => __( 'Enter your Sub title', 'optcare' ),
		]
	);
	
	$this->add_control(
		'subtitle1',
		[
			'label'       => __( 'Sub Title', 'optcare' ),
			'type'        => Controls_Manager::TEXTAREA,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => __( 'Enter your Sub title', 'optcare' ),
		]
	);

	$this->add_control(
		'text',
		[
			'label'       => __( 'Phone Number', 'optcare' ),
			'type'        => Controls_Manager::TEXTAREA,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => __( 'Enter your Description', 'optcare' ),
		]
	);

	
	$this->add_control(
		'btnlink',
		[
		'label' => __( 'Button Url', 'optcare' ),
		'type' => Controls_Manager::URL,
		'placeholder' => __( 'https://your-link.com', 'optcare' ),
		'show_external' => true,
		'default' => [
			'url' => '',
			'is_external' => true,
			'nofollow' => true,
		],
		
	]
	);
	

	$this->add_control(
		'title1',
		[
			'label'       => __( 'Title', 'optcare' ),
			'type'        => Controls_Manager::TEXTAREA,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => __( 'Enter your title', 'optcare' ),
		]
	);


		
	$this->add_control(
		'bttn',
		[
			'label'       => __( 'Button', 'optcare' ),
			'type'        => Controls_Manager::TEXT,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => esc_html__( 'Enter your Button Title', 'optcare' ),
			'default' => esc_html__('Read More', 'optcare'),
		]
	);	


	$this->add_control(
		'btnlink1',
		[
		'label' => __( 'Button Url', 'optcare' ),
		'type' => Controls_Manager::URL,
		'placeholder' => __( 'https://your-link.com', 'optcare' ),
		'show_external' => true,
		'default' => [
			'url' => '',
			'is_external' => true,
			'nofollow' => true,
		],
		
	]
	);

		$this->add_control(
				'bgimg',
				[
					'label' => esc_html__('Background image', 'optcare'),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);	

			$this->add_control(
				'bgimg1',
				[
					'label' => esc_html__('Background image', 'optcare'),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);	

			$this->add_control(
				'bgimg2',
				[
					'label' => esc_html__('Background image', 'optcare'),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);	

			$this->add_control(
				'bttn',
				[
					'label'       => __( 'Button', 'optcare' ),
					'type'        => Controls_Manager::TEXT,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'Enter your Button Title', 'optcare' ),
					'default' => esc_html__('Read More', 'optcare'),
				]
			);
	

			$this->add_control(
				'vlink',
				[
				  'label' => __( 'Video Url', 'optcare' ),
				  'type' => Controls_Manager::URL,
				  'placeholder' => __( 'https://your-link.com', 'optcare' ),
				  'show_external' => true,
				  'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				  ],
				
			   ]
			);	
			$this->add_control(
				'contact_us_form',
				[
					'label'       => __( 'Contact Form 7 Url', 'optcare' ),
					'type'        => Controls_Manager::TEXTAREA,
					'dynamic'     => [
						'active' => true,
					],
					'placeholder' => __( 'Enter your Contact Form 7 Url', 'optcare' ),
					'default'     => __( '', 'optcare' ),
				]
			);			
		
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 

function datepicker () {
	if ($("#datepicker").length) {
		$("#datepicker").datepicker();
	};
}
//put the code above the line 

  });
</script>';


?>


        
		
		  <!-- contact-section -->
		  <section class="contact-section p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="bg-layer"></div>
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
				<div class="pattern-1" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);"></div>
				<?php else :?>	
				<div class="noimage"></div>
				<?php endif;?>
				
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
				<div class="pattern-2" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);"></div>
				<?php else :?>	
				<div class="noimage"></div>
				<?php endif;?>
            </div>
            <div class="auto-container">
                <div class="sec-title centred light mb_45">
                    <span class="sub-title"><?php echo $settings['subtitle'];?></span>
                    <h2><?php echo $settings['title'];?></h2>
                </div>
                <div class="support-box p_relative centred">
                    <div class="icon-box"><img src="assets/images/icons/icon-2.png" alt=""></div>
                    <h3><?php echo $settings['subtitle1'];?> <a href="tel:<?php echo esc_url($settings['btnlink']['url']);?>"><?php echo $settings['text'];?></a></h3>
                </div>
                <div class="row clearfix">
                    <div class="col-lg-4 col-md-12 col-sm-12 form-column">
                        <div class="form-inner">
                            <h3><?php echo $settings['title1'];?></h3>

                            <?php echo do_shortcode( $settings['contact_us_form'] );?>
							
                        </div>
                    </div>
					<div class="col-lg-8 col-md-12 col-sm-12 video-column">              
						<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
							<div class="video-inner" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
								<div class="video-btn">
									<a href="<?php echo esc_url($settings['vlink']['url']);?>" class="lightbox-image" data-caption=""><i class="fas fa-play"></i></a>
								</div>
							</div>
							<?php else :?>	
								<div class="noimage"></div>
							<?php endif;?> 
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- contact-section end -->
             
		<?php 
	}

}