<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H1_Service_Section extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h1_service_section';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H1 Service Section', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h1_service_section',
			[
				'label' => esc_html__( 'H1 Service Section', 'optcare' ),
			]
		);
				
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
	

	$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'optcare' ),
			]
		);

	$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'optcare' ),
			]
		);


		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'optcare'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);	

		$this->add_control(
			'bgimg1',
			[
				'label' => esc_html__('Background image', 'optcare'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);			

		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Feature Block', 'optcare' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'optcare')],
							],
						'fields' => 
							[		
																	
										'block_title'=>	
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

									'block_icons'=>
										
									[
										'name' => 'block_icons',
										'label' => esc_html__('Enter The icons', 'optcare'),
										'type' => Controls_Manager::ICONS,
																
									],	

									'block_title1'=>	
									[
										'name' => 'block_title1',
										'label' => esc_html__('Title', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],
									
										'block_text'=>
									
									[
										'name' => 'block_text',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],	
									
									'block_text1'=>
									
									[
										'name' => 'block_text1',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

									'block_text2'=>
									
									[
										'name' => 'block_text2',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

									'block_text3'=>
									
									[
										'name' => 'block_text3',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

									'block_text4'=>
									
									[
										'name' => 'block_text4',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

									'block_image'=>

									[
										'name' => 'block_image',
										'label' => __( 'Image', 'optcare' ),
										'type' => Controls_Manager::MEDIA,
										'default' => ['url' => Utils::get_placeholder_image_src(),],
									  ],	

									  'block_alt_text'=>

									  [
										'name' => 'block_alt_text',
										'label' => esc_html__('Alt Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('iamge', 'optcare')
									],
									
											
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
 <!-- service-section -->
 <section class="service-section p_relative bg-color-1">
            <div class="pattern-layer">
               
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
				<div class="pattern-1" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);"></div>
				<?php else :?>	
				<div class="noimage"></div>
				<?php endif;?>
				
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
				<div class="pattern-2" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);"></div>
				<?php else :?>	
				<div class="noimage"></div>
				<?php endif;?>
				
            </div>
            <div class="auto-container">
                <div class="sec-title centred mb_50">
                    <span class="sub-title"><?php echo $settings['subtitle'];?></span>
                    <h2><?php echo $settings['title'];?></h2>
                </div>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_70 centred">
                        <ul class="tab-btns tab-buttons clearfix">
						
							<?php foreach($settings['repeat'] as $key=>$item):?>
						
						
                            <li class="tab-btn <?php if($key == 1) echo 'active-btn';?>" data-tab="#id-<?php echo esc_attr($key);?>">
                                <div class="icon-box"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></div>
                                <h4><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                            </li>
							
							<?php endforeach; ?>
                            
                        </ul>
                    </div>
                    <div class="tabs-content">
					
						<?php foreach($settings['repeat'] as $key=>$item):?>
					
                        <div class="tab <?php if($key == 1) echo 'active-tab';?>" id="id-<?php echo esc_attr($key);?>">
                            <div class="inner-box">
                                <div class="row clearfix">
                                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                        <div class="content_block_two">
                                            <div class="content-box">
                                                <div class="text">
                                                    <h3><?php echo wp_kses($item['block_title1'], $allowed_tags);?></h3>
                                                    <p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                    <p><?php echo wp_kses($item['block_text1'], $allowed_tags);?></p>
                                                </div>
                                                <ul class="list-style-one clearfix">
                                                    <li><?php echo wp_kses($item['block_text2'], $allowed_tags);?></li>
                                                    <li><?php echo wp_kses($item['block_text3'], $allowed_tags);?></li>
                                                    <li><?php echo wp_kses($item['block_text4'], $allowed_tags);?></li>
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                        <div class="image_block_two">
                                            <div class="image-box p_relative d_block">
                                                <figure class="image p_relative d_block">
													<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
													<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
                        
                    </div>
                </div>
            </div>
        </section>
        <!-- service-section end -->
   
		<?php 
	}

}