<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H2_Funfact_Section extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h2_funfact_section';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H2 Funfact Section', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h2_funfact_section',
			[
				'label' => esc_html__( 'H2 Funfact Section', 'optcare' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);

		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Feature Block', 'optcare' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'optcare')],
							],
						'fields' => 
							[		
																	
										'block_title'=>	
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

									'block_icons'=>
										
									[
										'name' => 'block_icons',
										'label' => esc_html__('Enter The icons', 'optcare'),
										'type' => Controls_Manager::ICONS,
																
									],	
									
										'block_text'=>
									
									[
										'name' => 'block_text',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

										'ff_stop'=>

									[
										'name' => 'ff_stop',
										'label' => esc_html__('Counter Stop', 'optcare'),
										'type' => Controls_Manager::TEXT,
										'default' => esc_html__('', 'hekim')
									],	
									
										
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		
	 <!-- funfact-style-two -->
	 <section class="funfact-style-two p_relative">
            <div class="auto-container">
                <div class="inner-container bg-color-2 p_relative">

                <?php foreach($settings['repeat'] as $item):?>	
                    <div class="counter-block-one wow slideInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                        <div class="inner-box">
                            <div class="icon-box p_relative d_block fs_60"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></div>
                            <div class="count-outer count-box">
                                <span class="count-text" data-stop="<?php echo esc_attr($item['ff_stop']);?>" data-speed="3000" ><?php echo wp_kses($item['block_title'], $allowed_tags);?></span>
                            </div>
                            <p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                        </div>
                    </div>
				<?php endforeach; ?>
                    
                </div>
            </div>
        </section>
        <!-- funfact-style-two end -->
   
		<?php 
	}

}