<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H2_Project extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h2_project';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H2 Project', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h2_project',
			[
				'label' => esc_html__( 'H2 Project', 'optcare' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Feature Block', 'optcare' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'optcare')],
							],
						'fields' => 
							[		
									
								
								'block_image'=>								
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'optcare' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],	

								'block_icons'=>	
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'optcare'),
									'type' => Controls_Manager::ICONS,
															
								],

								'block_btnlink'=>	

								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'optcare' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'optcare' ),
									'show_external' => true,
									'default' => [
									  'url' => '',
									  'is_external' => true,
									  'nofollow' => true,
									],
								 ],
								
									'block_title'=>	
								[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
								],


									'block_subtitle'=>	
								[
										'name' => 'block_subtitle',
										'label' => esc_html__('Subtitle', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
								],	

			
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>


				<?php
					echo '
					<script>
				jQuery(document).ready(function($)
				{

				//put the js code under this line 

				if ($(".project-carousel-2").length) {
					$(".project-carousel-2").owlCarousel({
						loop:true,
						margin:30,
						nav:true,
						smartSpeed: 500,
						autoplay: 1000,
						responsive:{
							0:{
								items:1
							},
							480:{
								items:2
							},
							600:{
								items:3
							},
							800:{
								items:4
							},			
							1200:{
								items:5
							}
			
						}
					});    		
				}

				//put the code above the line 

				});
				</script>';


				?>
        
		 <!-- project-section -->
		 <section class="project-section alternat-2 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container">
                <div class="project-carousel-2 owl-carousel owl-theme owl-dots-none owl-nav-none">
					<?php foreach($settings['repeat'] as $item):?>	
						<div class="project-block-one">
							<div class="inner-box">
								<figure class="image-box"><img src="<?php echo esc_url($item['block_image']['url']);?>" alt=""></figure>
								<div class="view-btn"><a href="<?php echo esc_url($item['block_image']['url']);?>" class="lightbox-image" data-fancybox="gallery"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></div>
								<div class="text">
									<h3><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h3>
									<span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
								</div>
							</div>
						</div>
					<?php endforeach; ?>
                </div>
            </div>
        </section>
        <!-- project-section end --> 

		
		<?php 
	}

}