<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H2_Skills_Right extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h2_skills_right';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H2 Skills Right', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h2_skills_right',
			[
				'label' => esc_html__( 'H2 Skills Right', 'optcare' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);	
	
	
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Skill Block', 'optcare' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'optcare')],
					],
				'fields' => 
					[
						'block_title' =>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'optcare'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'optcare')
						],
						'ff_stop' =>
						[
							'name' => 'ff_stop',
							'label' => esc_html__('Counter Stop', 'optcare'),
							'type' => Controls_Manager::TEXT,
							'default' => esc_html__('', 'hekim')
						],
						'ff_sing' =>
						[
							'name' => 'ff_sing',
							'label' => esc_html__('Counter Sing', 'optcare'),
							'type' => Controls_Manager::TEXT,
							'default' => esc_html__('', 'hekim')
						],
					],
				'title_field' => '{{block_title}}',
			 ]
	);
		
				
		$this->end_controls_section();	
						
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		
	   <!-- skills-section -->
	   <section class="<?php echo esc_attr($settings['sec_class']);?>">
			<div class="progress-box">
				<?php foreach($settings['repeat'] as $item):?>
					<div class="progress-box p_relative d_block mb_25">
						<h5><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
						<div class="bar">
							<div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"></div>
							<div class="count-text"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div>
						</div>
					</div>
				<?php endforeach; ?>
			</div>
        </section>
        <!-- skills-section end -->
             
		<?php 
	}

}