<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H2_Testimonial extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h2_testimonial';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H2 Testimonial', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h2_testimonial',
			[
				'label' => esc_html__( 'H2 Testimonial', 'optcare' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
	

	$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'optcare' ),
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'optcare' ),
			]
		);

		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 12,
				'step'    => 1,
			]
		);


		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Feature Block', 'optcare' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'optcare')],
							],
						'fields' => 
							[	

									'block_text'=>
										
									[
										'name' => 'block_text',
										'label' => esc_html__('Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')

									],	

									'block_image'=>

									[
										'name' => 'block_image',
										'label' => __( 'Image', 'optcare' ),
										'type' => Controls_Manager::MEDIA,
										'default' => ['url' => Utils::get_placeholder_image_src(),],
									  ],

									  'block_alt_text'=>

									  [
										'name' => 'block_alt_text',
										'label' => esc_html__('Alt Text', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('iamge', 'optcare')
										],
																		
										'block_title'=>	
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],

									'block_subtitle'=>	
											
									[
										'name' => 'block_subtitle',
										'label' => esc_html__('Subtitle', 'optcare'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'optcare')
									],	
									
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

				<?php
					echo '
					<script>
				jQuery(document).ready(function($)
				{

				//put the js code under this line 

				if ($(".single-item-carousel").length) {
					$(".single-item-carousel").owlCarousel({
						loop:true,
						margin:30,
						nav:true,
						smartSpeed: 500,
						autoplay: 1000,
						responsive:{
							0:{
								items:1
							},
							480:{
								items:1
							},
							600:{
								items:1
							},
							800:{
								items:1
							},			
							1200:{
								items:1
							}
			
						}
					});    		
				}

				//put the code above the line 

				});
				</script>';


				?>

        
		
		 <!-- testimonial-style-two -->
		 <section class="testimonial-style-two pt_100 <?php echo esc_attr($settings['sec_class']);?>">
			
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-xl-<?php echo esc_attr($settings['column'], true );?> col-lg-12 col-md-12 content-column">
                        <div class="content_block_six">
                            <div class="content-box p_relative z_2">
                                <div class="sec-title p_relative mb_35">
                                    <span class="sub-title"><?php echo $settings['subtitle'];?></span>
                                    <h2><?php echo $settings['title'];?></h2>
                                </div>
                                <div class="single-item-carousel owl-carousel owl-theme owl-nav-none dots-style-one">
									<?php foreach($settings['repeat'] as $item):?>
										<div class="testimonial-content">
											<div class="text p_relative d_block">
												<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
											</div>
											<div class="author-box">
												<figure class="author-thumb">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
												<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
												</figure>
												<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
												<span class="designation"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
											</div>
										</div>
									<?php endforeach; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
			
        </section>
        <!-- testimonial-style-two end -->

             
		<?php 
	}

}