<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;
use Elementor\Utils;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H3_Blog extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h3_blog';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H3 Blog', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h3_blog',
			[
				'label' => esc_html__( 'H3 Blog', 'optcare' ),
			]
		);
		$this->add_control(
            'thumb', 
				[
					'label'   => esc_html__( 'Choose Post Image', 'atrix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Meta Box Image', 'atrix' ),
						'style2' => esc_html__( 'Dafult Thumbnail', 'atrix' ),
					),
				]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'optcare' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'optcare' ),
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'optcare' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'optcare' ),
				'default' => esc_html__('Read More', 'optcare'),
			]
		);	
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'optcare' ),
					'6'   => esc_html__( 'Two Column', 'optcare' ),
					'4'   => esc_html__( 'Three Column', 'optcare' ),
					'3'   => esc_html__( 'Four Column', 'optcare' ),
					'2'   => esc_html__( 'Six Column', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
		
		$this->end_controls_section();
	
		$this->start_controls_section(
				'content_section',
				[
					'label' => __( 'Blog Block', 'optcare' ),
					'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				]
			);
			
		
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'optcare' ),
					'title'      => esc_html__( 'Title', 'optcare' ),
					'menu_order' => esc_html__( 'Menu Order', 'optcare' ),
					'rand'       => esc_html__( 'Random', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'optcare' ),
					'ASC'  => esc_html__( 'ASC', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'query_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'optcare' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude posts, pages, etc. by ID with comma separated.', 'optcare' ),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'optcare'),
				  'options' => get_blog_categories()
				]
		);
	
		
		$this->end_controls_section();

	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        
        $paged = optcare_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-optcare' );
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => optcare_set( $settings, 'query_number' ),
			'orderby'        => optcare_set( $settings, 'query_orderby' ),
			'order'          => optcare_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if ( optcare_set( $settings, 'query_exclude' ) ) {
			$settings['query_exclude'] = explode( ',', $settings['query_exclude'] );
			$args['post__not_in']      = optcare_set( $settings, 'query_exclude' );
		}
		if( optcare_set( $settings, 'query_category' ) ) $args['category_name'] = optcare_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{ ?>

        <!-- news-section -->
        <section class="news-section p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-two mb_50 centred">
                    <h5 class="mb_20"><?php echo $settings['subtitle'];?></h5>
                    <h2 class="d_block fs_40 fw_bold mb_25"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php while ( $query->have_posts() ) : $query->the_post();

					$meta_image = get_post_meta( get_the_id(), 'meta_image', true );

					?>
				
                    <div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12 news-block">
                        <div class="news-block-one wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box">
                                <figure class="image-box">
								
                                    <?php  if ( 'style1' === $settings['thumb'] ) : ?>
									<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
									<?php endif; ?> 

									<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
									<?php  the_post_thumbnail();    ?>
									<?php endif; ?> 	
									
                                    <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><i class="fas fa-link"></i></a>
                                </figure>
                                <div class="lower-content">
                                    <div class="inner">
									
									
                                        <div class="category"><?php comments_number(); ?></div>
										
										
                                        <h3><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
										
                                        <ul class="post-info clearfix">
										
										
										
                                            <li><i class="icon-34"></i><a href="<?php echo get_day_link( get_the_time( 'Y' ), get_the_time( 'm' ), get_the_time( 'd' ) ); ?>"><?php echo get_the_date(); ?></a> </li>
											
											
											
                                            <li><i class="icon-35"></i><a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta('ID') )); ?>"><?php the_author(); ?></a> </li>
											
											
											
                                        </ul>
                                        <p><?php echo optcare_trim(get_the_content(), $settings['text_limit']); ?></p>
										
										<?php if($settings['bttn']): ?>
                                        <div class="link"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php echo $settings['bttn'];?></a></div>
										<?php endif; ?>
										
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
					
					<?php endwhile; ?>
					
                </div>
            </div>
        </section>
        <!-- news-section end -->
		
        <?php }
		wp_reset_postdata();
	}

}