<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class H3_Service extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_h3_service';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'H3 Service', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'h3_service',
			[
				'label' => esc_html__( 'H3 Service', 'optcare' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);


		$this->add_control(
			'icons',
				[
					'label' => esc_html__('Enter The icons', 'optcare'),
					'type' => Controls_Manager::ICONS,
				]
		);

		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'optcare' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'optcare' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);

	$this->add_control(
		'title',
		[
			'label'       => __( 'Title', 'optcare' ),
			'type'        => Controls_Manager::TEXTAREA,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => __( 'Enter your title', 'optcare' ),
		]
	);

	$this->add_control(
		'text',
		[
			'label'       => __( 'Description Text', 'optcare' ),
			'type'        => Controls_Manager::TEXTAREA,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => __( 'Enter your Description', 'optcare' ),
		]
	);	

	
	$this->add_control(
		'bttn',
		[
			'label'       => __( 'Button', 'optcare' ),
			'type'        => Controls_Manager::TEXT,
			'dynamic'     => [
				'active' => true,
			],
			'placeholder' => esc_html__( 'Enter your Button Title', 'optcare' ),
			'default' => esc_html__('Read More', 'optcare'),
		]
	);	

	
	$this->add_control(
		'btnlink1',
		[
		  'label' => __( 'Button Url', 'optcare' ),
		  'type' => Controls_Manager::URL,
		  'placeholder' => __( 'https://your-link.com', 'optcare' ),
		  'show_external' => true,
		  'default' => [
			'url' => '',
			'is_external' => true,
			'nofollow' => true,
		  ],
		
	   ]
	);
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<!-- service-style-three -->

			<div class="service-block-two wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms <?php echo esc_attr($settings['sec_class']);?>">
				<div class="inner-box">
					<div class="icon-box"><i class="<?php echo str_replace("icon ", "", esc_attr( $settings['icons']['value']));?>"></i></div>
					<h3><a href="<?php echo esc_url($settings['btnlink']['url']);?>"><?php echo $settings['title'];?></a></h3>
					<p><?php echo $settings['text'];?></p>
					<div class="link-text"><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a></div>
				</div>
			</div>

		<!-- service-style-three end -->
		
		<?php 
	}

}