<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Portfolios2 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_portfolios2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Portfolios Two', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'portfolios2',
			[
				'label' => esc_html__( 'Portfolios Two', 'optcare' ),
			]
		);
		
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		$this->add_control(
			'number',
			[
				'label'   => esc_html__( 'Number of post', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'cat_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'optcare' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude categories, etc. by ID with comma separated.', 'optcare' ),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'optcare' ),
					'ASC'  => esc_html__( 'ASC', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'optcare' ),
					'title'      => esc_html__( 'Title', 'optcare' ),
					'menu_order' => esc_html__( 'Menu Order', 'optcare' ),
					'rand'       => esc_html__( 'Random', 'optcare' ),
				),
			]
		);
		$this->end_controls_section();
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$paged = optcare_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-optcare' );
		$args = array(
			'post_type'      => 'optcare_project',
			'posts_per_page' => optcare_set( $settings, 'number' ),
			'orderby'        => optcare_set( $settings, 'query_orderby' ),
			'order'          => optcare_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		$terms_array = explode(",",optcare_set( $settings, 'cat_exclude' ));
		if(optcare_set( $settings, 'cat_exclude' )) $args['tax_query'] = array(array('taxonomy' => 'project_cat','field' => 'id','terms' => $terms_array,'operator' => 'NOT IN',));
		$allowed_tags = wp_kses_allowed_html('post');
		$query = new \WP_Query( $args );
		$t = '';
		$data_filtration = '';
		$data_posts = '';
		if ( $query->have_posts() ) 
		{
		ob_start();
		?>
  
		<?php 
            $count = 0; 
            $fliteration = array();
            while( $query->have_posts() ): $query->the_post();
            global  $post;
            $meta = ''; //printr($meta);
            $meta1 = ''; //_WSH()->get_meta();
            $post_terms = get_the_terms( get_the_id(), 'project_cat');// printr($post_terms); exit();
            foreach( (array)$post_terms as $pos_term ) $fliteration[$pos_term->term_id] = $pos_term;
            $temp_category = get_the_term_list(get_the_id(), 'project_cat', '', ', ');
            
            $post_terms = wp_get_post_terms( get_the_id(), 'project_cat'); 
            $term_slug = '';
            if( $post_terms ) foreach( $post_terms as $p_term ) $term_slug .= $p_term->slug.' ';
        
            ?>
	
				
			<div class="masonry-item small-column all <?php echo esc_attr($term_slug); ?>">
				<div class="project-block-one">
					<div class="inner-box">
						<figure class="image-box"><?php the_post_thumbnail(); ?></figure>
						<div class="view-btn"><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'image_link', true ));?>" class="lightbox-image" data-fancybox="gallery"><i class="icon-33"></i></a></div>
						<div class="text">
							<h3><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'page_link', true ));?>"><?php the_title(); ?></a></h3>
							<span><?php echo (get_post_meta( get_the_id(), 'meta_subtitle', true ));?></span>
						</div>
					</div>
				</div>
			</div>
				
	
				
            <?php endwhile;?>

            <?php wp_reset_postdata();
            $data_posts = ob_get_contents();
            ob_end_clean();
            
            ob_start();?>
            
            <?php $terms = get_terms(array('project_cat')); ?>
			
			
		 <!-- portfolio-page-section -->
		 
        <section class="portfolio-page-section p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container">
                <div class="sortable-masonry">
                    <div class="filters mb_50">
                        <ul class="filter-tabs filter-btns clearfix centred">
						
                            <li class="active filter" data-role="button" data-filter=".all"><?php esc_attr_e('All', 'optcare');?></li>
							
							<?php foreach( $fliteration as $t ): ?>
                            <li class="filter" data-role="button" data-filter=".<?php echo esc_attr(optcare_set( $t, 'slug' )); ?>"><?php echo optcare_set( $t, 'name'); ?></li>
							<?php endforeach;?>
                            
                        </ul>
                    </div>
					
					
					
                    <div class="items-container clearfix">
                       <?php echo $data_posts; ?>
                    </div>
					
                </div>
            </div>
        </section>
		
        <!-- portfolio-page-section end -->
			
			
			
        

    	<?php }
	}

}
