<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Team2 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_team2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team 2', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'team2',
			[
				'label' => esc_html__( 'Team 2', 'optcare' ),
			]
		);
		
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'optcare' ),
					'6'   => esc_html__( 'Two Column', 'optcare' ),
					'4'   => esc_html__( 'Three Column', 'optcare' ),
					'3'   => esc_html__( 'Four Column', 'optcare' ),
					'2'   => esc_html__( 'Six Column', 'optcare' ),
				),
			]
		);

		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'optcare' ),
					'title'      => esc_html__( 'Title', 'optcare' ),
					'menu_order' => esc_html__( 'Menu Order', 'optcare' ),
					'rand'       => esc_html__( 'Random', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'optcare' ),
					'ASC'  => esc_html__( 'ASC', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'query_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'optcare' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude posts, pages, etc. by ID with comma separated.', 'optcare' ),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'optcare'),
				  'options' => get_team_categories()
				]
		);
		
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        
        $paged = optcare_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-optcare' );
		$args = array(
			'post_type'      => 'optcare_team',
			'posts_per_page' => optcare_set( $settings, 'query_number' ),
			'orderby'        => optcare_set( $settings, 'query_orderby' ),
			'order'          => optcare_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if ( optcare_set( $settings, 'query_exclude' ) ) {
			$settings['query_exclude'] = explode( ',', $settings['query_exclude'] );
			$args['post__not_in']      = optcare_set( $settings, 'query_exclude' );
		}
		if( optcare_set( $settings, 'query_category' ) ) $args['team_cat'] = optcare_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{
		?>
  
	   <!-- team-style-two -->
        <section class="team-style-two team-page-2 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
					<?php while ( $query->have_posts() ) : $query->the_post(); ?>	
						<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12 team-block">
							<div class="team-block-two wow fadeInUp animated animated" data-wow-delay="00ms" data-wow-duration="1500ms">
								<div class="inner-box">
								
									<figure class="image-box">
										<?php the_post_thumbnail(); ?>
									</figure>
									
									<div class="lower-content p_relative d_block">
										<div class="share-box p_absolute">
										
											<a href="#" class="share-icon fs_14 d_iblock"><i class="icon-37"></i></a>
											
											<?php	
												$icons = get_post_meta( get_the_id(), 'social_profile', true );
													if ( ! empty( $icons ) ) :?>
											
											<ul class="share-links p_absolute clearfix">
											
											<?php
													foreach ( $icons as $h_icon ) :
													$header_social_icons = json_decode( urldecode( optcare_set( $h_icon, 'data' ) ) );
													if ( optcare_set( $header_social_icons, 'enable' ) == '' ) {
													continue;
													}
													$icon_class = explode( '-', optcare_set( $header_social_icons, 'icon' ) );?>
												<li><a href="<?php echo optcare_set( $header_social_icons, 'url' ); ?>"><i class="fab <?php echo esc_attr( optcare_set( $header_social_icons, 'icon' ) ); ?>"></i></a></li>
											  
												<?php endforeach; ?>
											</ul>
											
											<?php endif; ?>
											
											
										</div>
										
										<h3><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'team_link', true ));?>"><?php the_title(); ?></a></h3>
										
										<span class="designation"><?php echo (get_post_meta( get_the_id(), 'designation', true ));?></span>
										
									</div>
								</div>
							</div>
						</div>
					  <?php endwhile; ?>  
                </div>
            </div>
        </section>
        <!-- team-style-two end -->
  
           
        <?php }
		wp_reset_postdata();
	}

}