<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Team_Details extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_team_details';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Details', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'team_details',
			[
				'label' => esc_html__( 'Team Details', 'optcare' ),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'optcare' ),
			]
		);
		

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'optcare' ),
			]
		);
		
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'optcare' ),
			]
		);
		
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
		
		$this->end_controls_section();


		// New Tab#1

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Team Details Block', 'optcare' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'optcare')],
					],
				'fields' => 
					[	
							'block_text'=>
						
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'optcare'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'optcare')
						],

						'block_text1'=>
						
						[
							'name' => 'block_text1',
							'label' => esc_html__('Text', 'optcare'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'optcare')
						],
							
					],
				'title_field' => '{{block_title}}',
			]
		);

		$this->end_controls_section();	

		// New Tab#2

		$this->start_controls_section(
			'content_section1',
			[
				'label' => __( 'Contact Block', 'optcare' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		'repeat1', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'optcare')],
					],
				'fields' => 
					[	
							'block_text'=>
						
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'optcare'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'optcare')
						],

						'block_text1'=>
						
						[
							'name' => 'block_text1',
							'label' => esc_html__('Text', 'optcare'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'optcare')
						],

						'block_btnlink'=>
						
						[
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'optcare' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'optcare' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						 ],
							
					],
				'title_field' => '{{block_title}}',
			]
		);

		$this->end_controls_section();	

		// New Tab#3

		$this->start_controls_section(
			'content_section2',
			[
				'label' => __( 'Icon Block', 'optcare' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		'repeat2', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'optcare')],
					],
				'fields' => 
					[	
							'block_btnlink'=>
						
							[
								'name' => 'block_btnlink',
								'label' => __( 'Button Url', 'optcare' ),
								'type' => Controls_Manager::URL,
								'placeholder' => __( 'https://your-link.com', 'optcare' ),
								'show_external' => true,
								'default' => [
								  'url' => '',
								  'is_external' => true,
								  'nofollow' => true,
								],
							 ],
							
						'block_icons'=>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'optcare'),
							'type' => Controls_Manager::ICONS,							
						],


					],
				'title_field' => '{{block_title}}',
			]
		);

		$this->end_controls_section();	

		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

        <!-- team-details -->
        <section class="team-details p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    
                    <div class="col-lg-12 col-md-12 col-sm-12 content-column">
                        <div class="team-details-content">
                            <div class="team-info">
                                <h2><?php echo $settings['title'];?></h2>
                                <span class="designation"><?php echo $settings['subtitle'];?></span>
                                <p><?php echo $settings['text'];?></p>

                                <ul class="list clearfix">
									<?php foreach($settings['repeat'] as $item):?>	
                                    	<li><span><?php echo wp_kses($item['block_text'], $allowed_tags);?></span><?php echo wp_kses($item['block_text1'], $allowed_tags);?></li>
									<?php endforeach; ?>

									<?php foreach($settings['repeat1'] as $item):?>	
                                    	<li><span><?php echo wp_kses($item['block_text'], $allowed_tags);?></span><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_text1'], $allowed_tags);?></a></li>
                                   <?php endforeach; ?>

                                </ul>

                                <ul class="social-link clearfix">
									<?php foreach($settings['repeat2'] as $item):?>	
                                    	<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>

                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- team-details end -->
			 

		<?php 
	}

}