<?php

namespace OPTCAREPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Team_Element_2 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'optcare_team_element_2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Element 2', 'optcare' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'optcare' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'team_element_2',
			[
				'label' => esc_html__( 'Team Element 2', 'optcare' ),
			]
		);
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'optcare' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'optcare' ),
					'title'      => esc_html__( 'Title', 'optcare' ),
					'menu_order' => esc_html__( 'Menu Order', 'optcare' ),
					'rand'       => esc_html__( 'Random', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'optcare' ),
					'ASC'  => esc_html__( 'ASC', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'query_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'optcare' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude posts, pages, etc. by ID with comma separated.', 'optcare' ),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'optcare'),
				  'options' => get_team_categories()
				]
		);
		$this->end_controls_section();
		
		
		
		$this->start_controls_section(
				'content_section',
				[
					'label' => __( 'Team Block', 'optcare' ),
					'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				]
			);
			$this->add_control(
				'bgimg',
				[
					'label' => esc_html__('Background image', 'optcare'),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'optcare' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'optcare' ),
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'optcare' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'optcare' ),
				'default' => esc_html__('Read More', 'optcare'),
			]
		);
		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'optcare' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'optcare' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'optcare' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'optcare' ),
					'6'   => esc_html__( 'Two Column', 'optcare' ),
					'4'   => esc_html__( 'Three Column', 'optcare' ),
					'3'   => esc_html__( 'Four Column', 'optcare' ),
					'2'   => esc_html__( 'Six Column', 'optcare' ),
				),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'optcare' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'optcare' ),
			]
		);
		
		
	
		
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        
        $paged = optcare_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-optcare' );
		$args = array(
			'post_type'      => 'optcare_team',
			'posts_per_page' => optcare_set( $settings, 'query_number' ),
			'orderby'        => optcare_set( $settings, 'query_orderby' ),
			'order'          => optcare_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if ( optcare_set( $settings, 'query_exclude' ) ) {
			$settings['query_exclude'] = explode( ',', $settings['query_exclude'] );
			$args['post__not_in']      = optcare_set( $settings, 'query_exclude' );
		}
		if( optcare_set( $settings, 'query_category' ) ) $args['team_cat'] = optcare_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{
		?>


			<?php
				echo '
				<script>
			jQuery(document).ready(function($)
			{

			//put the js code under this line 

			if ($(".three-item-carousel").length) {
				$(".three-item-carousel").owlCarousel({
					loop:true,
					margin:30,
					nav:true,
					smartSpeed: 500,
					autoplay: 1000,
					responsive:{
						0:{
							items:1
						},
						480:{
							items:1
						},
						600:{
							items:2
						},
						800:{
							items:2
						},			
						1200:{
							items:3
						}
		
					}
				});    		
			}

			//put the code above the line 

			});
			</script>';


			?>

        <section class="team-section p_relative <?php echo esc_attr($settings['sec_class']);?>">

            <div class="auto-container">

			<div class="three-item-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				
					<?php while ( $query->have_posts() ) : $query->the_post(); ?>
				
                    
                        <div class="team-block-one wow fadeInUp animated animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block pr_55">
                                <figure class="image-box p_relative d_block">
								
								
								<?php the_post_thumbnail(); ?>
								
								
								</figure>
                                <div class="lower-content p_absolute r_0 b_45 b_shadow_6 z_1 tran_5">
								
								
                                    <h3 class="d_block lh_30 mb_3 tran_5"><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'team_link', true ));?>" class="d_iblock color_black"><?php the_title(); ?></a></h3>
									
									
                                    <span class="designation p_relative d_block fs_16 lh_20 font_family_poppins tran_5"><?php echo (get_post_meta( get_the_id(), 'designation', true ));?></span>
									
									<?php	
											$icons = get_post_meta( get_the_id(), 'social_profile', true );
												if ( ! empty( $icons ) ) :?>
									
                                    <ul class="social-links clearfix p_absolute l_25 b_14 tran_5">
									
										<?php
												foreach ( $icons as $h_icon ) :
												$header_social_icons = json_decode( urldecode( optcare_set( $h_icon, 'data' ) ) );
												if ( optcare_set( $header_social_icons, 'enable' ) == '' ) {
												continue;
												}
												$icon_class = explode( '-', optcare_set( $header_social_icons, 'icon' ) );?>
									
                                        <li class="p_relative d_iblock pull-left mr_25"><a href="<?php echo optcare_set( $header_social_icons, 'url' ); ?>" class="d_iblock fs_15"><i class="fab <?php echo esc_attr( optcare_set( $header_social_icons, 'icon' ) ); ?>"></i></a></li>
										
										<?php endforeach; ?>
										
                                    </ul>
									
									<?php endif; ?>
									
                                </div>
                            </div>
                        </div>
                  
					
					<?php endwhile; ?>   
					
                </div>
            </div>
        </section>
  
           
        <?php }
		wp_reset_postdata();
	}

}
